@@ -12,10 +12,10 @@ import {
   INVOICE_ITEMS_CATEGORY_LABELS,
   INVOICE_PATIENT_PAYMENT_STATUSES_LABELS,
 } from './invoices';
+import { ENCOUNTER_TYPE_LABELS } from './encounters';
 import { NOTE_TYPE_LABELS } from './notes';
 import {
   REFERRAL_STATUS_LABELS,
-  APPOINTMENT_TYPE_LABELS,
   APPOINTMENT_STATUSES,
   IMAGING_REQUEST_STATUS_LABELS,
 } from './statuses';
@@ -39,7 +39,13 @@ import { DIAGNOSIS_CERTAINTY_LABELS, PATIENT_ISSUE_LABELS } from './diagnoses';
 import { DRUG_ROUTE_LABELS, REPEATS_LABELS } from './medications';
 import { PLACE_OF_DEATHS, MANNER_OF_DEATHS } from './deaths';
 import { LOCATION_AVAILABILITY_STATUS_LABELS } from './locations';
+import { TASK_FREQUENCY_UNIT_LABELS } from './tasks.js';
 import { IMAGING_TYPES } from './imaging';
+import {
+  REPEAT_FREQUENCY_LABELS,
+  REPEAT_FREQUENCY_UNIT_LABELS,
+  REPEAT_FREQUENCY_UNIT_PLURAL_LABELS,
+} from './appointments';
 
 type EnumKeys = keyof typeof registeredEnums;
 type EnumValues = typeof registeredEnums[EnumKeys];
@@ -52,7 +58,6 @@ type EnumEntries = [EnumKeys, EnumValues][];
  */
 export const registeredEnums = {
   APPOINTMENT_STATUSES,
-  APPOINTMENT_TYPE_LABELS,
   ATTENDANT_OF_BIRTH_LABELS,
   ASSET_NAME_LABELS,
   BIRTH_DELIVERY_TYPE_LABELS,
@@ -61,6 +66,7 @@ export const registeredEnums = {
   DIAGNOSIS_CERTAINTY_LABELS,
   DRUG_ROUTE_LABELS,
   EDUCATIONAL_ATTAINMENT_LABELS,
+  ENCOUNTER_TYPE_LABELS,
   IMAGING_TYPES,
   IMAGING_REQUEST_STATUS_LABELS,
   INJECTION_SITE_LABELS,
@@ -78,11 +84,15 @@ export const registeredEnums = {
   PLACE_OF_DEATHS,
   REFERRAL_STATUS_LABELS,
   REPEATS_LABELS,
+  REPEAT_FREQUENCY_LABELS,
+  REPEAT_FREQUENCY_UNIT_LABELS,
+  REPEAT_FREQUENCY_UNIT_PLURAL_LABELS,
   REPORT_DATA_SOURCE_LABELS,
   REPORT_DB_SCHEMA_LABELS,
   REPORT_DEFAULT_DATE_RANGES_LABELS,
   REPORT_STATUS_LABELS,
   SEX_LABELS,
+  TASK_FREQUENCY_UNIT_LABELS,
   SOCIAL_MEDIA_LABELS,
   TEMPLATE_TYPE_LABELS,
   TITLE_LABELS,
@@ -98,7 +108,6 @@ export const registeredEnums = {
  */
 export const translationPrefixes: Record<EnumKeys, string> = {
   APPOINTMENT_STATUSES: 'appointment.property.status',
-  APPOINTMENT_TYPE_LABELS: 'appointment.property.types',
   ATTENDANT_OF_BIRTH_LABELS: 'birth.property.attendantOfBirth',
   ASSET_NAME_LABELS: 'asset.property.name',
   BIRTH_DELIVERY_TYPE_LABELS: 'birth.property.birthDeliveryType',
@@ -107,6 +116,7 @@ export const translationPrefixes: Record<EnumKeys, string> = {
   DIAGNOSIS_CERTAINTY_LABELS: 'diagnosis.property.certainty',
   DRUG_ROUTE_LABELS: 'medication.property.route',
   EDUCATIONAL_ATTAINMENT_LABELS: 'patient.property.educationalAttainment',
+  ENCOUNTER_TYPE_LABELS: 'encounter.property.type',
   IMAGING_TYPES: 'imaging.property.type',
   IMAGING_REQUEST_STATUS_LABELS: 'imaging.property.status',
   INJECTION_SITE_LABELS: 'vaccine.property.injectionSite',
@@ -124,11 +134,15 @@ export const translationPrefixes: Record<EnumKeys, string> = {
   PLACE_OF_DEATHS: 'death.property.placeOfDeath',
   REFERRAL_STATUS_LABELS: 'referral.property.status',
   REPEATS_LABELS: 'medication.property.repeats',
+  REPEAT_FREQUENCY_LABELS: 'scheduling.property.repeatFrequency',
+  REPEAT_FREQUENCY_UNIT_LABELS: 'scheduling.property.repeatFrequencyUnit',
+  REPEAT_FREQUENCY_UNIT_PLURAL_LABELS: 'scheduling.property.repeatFrequencyUnitPlural',
   REPORT_DATA_SOURCE_LABELS: 'report.property.dataSource',
   REPORT_DB_SCHEMA_LABELS: 'report.property.schema',
   REPORT_DEFAULT_DATE_RANGES_LABELS: 'report.property.defaultDateRange',
   REPORT_STATUS_LABELS: 'report.property.status',
   SEX_LABELS: 'patient.property.sex',
+  TASK_FREQUENCY_UNIT_LABELS: 'task.property.frequencyUnit',
   SOCIAL_MEDIA_LABELS: 'patient.property.socialMedia',
   TEMPLATE_TYPE_LABELS: 'template.property.type',
   TITLE_LABELS: 'patient.property.title',
