@@ -2,6 +2,9 @@ import config from 'config';
 import defineExpress from 'express';
 
 import { settingsReaderMiddleware } from '@tamanu/settings/middleware';
+import { defineDbNotifier } from '@tamanu/shared/services/dbNotifier';
+import { NOTIFY_CHANNELS } from '@tamanu/constants';
+
 import { getAuditMiddleware } from './middleware/auditLog';
 
 import routes from './routes';
@@ -13,6 +16,9 @@ import { defineWebsocketService } from './services/websocketService';
 import { defineWebsocketClientService } from './services/websocketClientService';
 import { addFacilityMiddleware } from './addFacilityMiddleware';
 
+/**
+ * @param {import('./ApplicationContext').ApplicationContext} ctx
+ */
 export async function createApiApp({
   sequelize,
   reportSchemaStores,
@@ -23,15 +29,20 @@ export async function createApiApp({
   const express = defineExpress();
   const server = createServer(express);
 
-  const pg = await sequelize.connectionManager.getConnection();
+  const dbNotifier = await defineDbNotifier(sequelize.config, [
+    NOTIFY_CHANNELS.TABLE_CHANGED,
+    NOTIFY_CHANNELS.MATERIALIZED_VIEW_REFRESHED,
+  ]);
 
-  const websocketService = defineWebsocketService({ httpServer: server, pg });
+  const websocketService = defineWebsocketService({ httpServer: server, dbNotifier, models });
   const websocketClientService = defineWebsocketClientService({ config, websocketService, models });
 
   const { errorMiddleware } = addFacilityMiddleware(express);
 
   // Release the connection back to the pool when the server is closed
-  server.on('close', () => sequelize.connectionManager.releaseConnection(pg));
+  server.on('close', () => {
+    dbNotifier.close();
+  });
 
   express.use((req, res, next) => {
     req.models = models;
@@ -42,6 +53,7 @@ export async function createApiApp({
     req.language = req.headers['language'];
     req.websocketService = websocketService;
     req.websocketClientService = websocketClientService;
+    req.dbNotifier = dbNotifier;
 
     next();
   });
