@@ -10,15 +10,21 @@ referral.put('/:id', simplePut('Referral'));
 referral.post(
   '/$',
   asyncHandler(async (req, res) => {
-    const { models, body, db } = req;
-
+    const {
+      models,
+      body: { facilityId, ...body },
+      db,
+      settings,
+    } = req;
     req.checkPermission('create', 'Referral');
 
-    const getDefaultId = async type => models.SurveyResponseAnswer.getDefaultId(type);
+    const getDefaultId = async type =>
+      models.SurveyResponseAnswer.getDefaultId(type, settings[facilityId]);
     const updatedBody = {
       locationId: body.locationId || (await getDefaultId('location')),
       departmentId: body.departmentId || (await getDefaultId('department')),
       userId: req.user.id,
+      facilityId,
       ...body,
     };
 
