@@ -30,7 +30,7 @@ const defaultMapper = ({ name, code, id }) => ({ name, code, id });
 const extractDataId = ({ stringId }) => stringId.split('.').pop();
 const replaceDataLabelsWithTranslations = ({ data, translations }) => {
   const translationsByDataId = keyBy(translations, extractDataId);
-  return data.map(item => {
+  return data.map((item) => {
     const itemData = item instanceof Sequelize.Model ? item.dataValues : item; // if is Sequelize model, use the dataValues instead to prevent Converting circular structure to JSON error when destructing
     return { ...itemData, name: translationsByDataId[item.id]?.text || item.name };
   });
@@ -38,17 +38,18 @@ const replaceDataLabelsWithTranslations = ({ data, translations }) => {
 const ENDPOINT_TO_DATA_TYPE = {
   // Special cases where the endpoint name doesn't match the dataType
   ['facilityLocationGroup']: OTHER_REFERENCE_TYPES.LOCATION_GROUP,
+  ['bookableLocationGroup']: OTHER_REFERENCE_TYPES.LOCATION_GROUP,
   ['patientLabTestCategories']: REFERENCE_TYPES.LAB_TEST_CATEGORY,
   ['patientLabTestPanelTypes']: OTHER_REFERENCE_TYPES.LAB_TEST_PANEL,
   ['invoiceProducts']: OTHER_REFERENCE_TYPES.INVOICE_PRODUCT,
 };
-const getDataType = endpoint => ENDPOINT_TO_DATA_TYPE[endpoint] || endpoint;
+const getDataType = (endpoint) => ENDPOINT_TO_DATA_TYPE[endpoint] || endpoint;
 
 function createSuggesterRoute(
   endpoint,
   modelName,
   whereBuilder,
-  { mapper, searchColumn, extraReplacementsBuilder, includeBuilder },
+  { mapper, searchColumn, extraReplacementsBuilder, includeBuilder, orderBuilder },
 ) {
   suggestions.get(
     `/${endpoint}$`,
@@ -77,13 +78,16 @@ function createSuggesterRoute(
         : [];
       const suggestedIds = translations.map(extractDataId);
 
-      const whereQuery = whereBuilder(`%${searchQuery}%`, query);
+      const whereQuery = whereBuilder(`%${searchQuery}%`, query, req);
 
       const where = {
         [Op.or]: [
           whereQuery,
           {
-            id: { [Op.in]: suggestedIds },
+            // Wrap inside AND block to avoid being overwritten by whereQuery results
+            [Op.and]: {
+              id: { [Op.in]: suggestedIds },
+            },
             ...omit(whereQuery, 'name'),
           },
         ],
@@ -94,11 +98,16 @@ function createSuggesterRoute(
       }
 
       const include = includeBuilder?.(req);
+      const order = orderBuilder?.(req);
 
       const results = await model.findAll({
         where,
         include,
-        order: [positionQuery, [Sequelize.literal(`"${modelName}"."${searchColumn}"`), 'ASC']],
+        order: [
+          ...(order ? [order] : []),
+          positionQuery,
+          [Sequelize.literal(`"${modelName}"."${searchColumn}"`), 'ASC'],
+        ],
         replacements: {
           positionMatch: searchQuery,
           ...extraReplacementsBuilder(query),
@@ -107,7 +116,7 @@ function createSuggesterRoute(
       });
 
       // Allow for async mapping functions (currently only used by location suggester)
-      const data = await Promise.all(results.map(r => mapper(r)));
+      const data = await Promise.all(results.map((r) => mapper(r)));
 
       res.send(isTranslatable ? replaceDataLabelsWithTranslations({ data, translations }) : data);
     }),
@@ -189,12 +198,11 @@ function createAllRecordsRoute(
         return;
       }
 
-      const translatedStrings = await models.TranslatedString.getReferenceDataTranslationsByDataType(
-        {
+      const translatedStrings =
+        await models.TranslatedString.getReferenceDataTranslationsByDataType({
           language: query.language,
           refDataType: getDataType(endpoint),
-        },
-      );
+        });
 
       const translatedResults = replaceDataLabelsWithTranslations({
         data: mappedResults,
@@ -207,7 +215,11 @@ function createAllRecordsRoute(
   );
 }
 
-function createSuggesterCreateRoute(endpoint, modelName, { creatingBodyBuilder, mapper }) {
+function createSuggesterCreateRoute(
+  endpoint,
+  modelName,
+  { creatingBodyBuilder, mapper, afterCreated },
+) {
   suggestions.post(
     `/${endpoint}/create`,
     asyncHandler(async (req, res) => {
@@ -216,6 +228,9 @@ function createSuggesterCreateRoute(endpoint, modelName, { creatingBodyBuilder,
 
       const body = await creatingBodyBuilder(req);
       const newRecord = await models[modelName].create(body, { returning: true });
+      if (afterCreated) {
+        await afterCreated(req, newRecord);
+      }
       const mappedRecord = await mapper(newRecord);
       res.send(mappedRecord);
     }),
@@ -255,22 +270,117 @@ const VISIBILITY_CRITERIA = {
   visibilityStatus: VISIBILITY_STATUSES.CURRENT,
 };
 
-REFERENCE_TYPE_VALUES.forEach(typeName => {
+const afterCreatedReferenceData = async (req, newRecord) => {
+  const { models } = req;
+
+  if (newRecord.type === REFERENCE_TYPES.TASK_TEMPLATE) {
+    await models.TaskTemplate.create({ referenceDataId: newRecord.id });
+  }
+};
+
+const referenceDataBodyBuilder = ({ type, name }) => {
+  if (!name) {
+    throw new ValidationError('Name is required');
+  }
+
+  if (!type) {
+    throw new ValidationError('Type is required');
+  }
+
+  const code = `${camelCase(name)}-${customAlphabet('1234567890ABCDEFGHIJKLMNPQRSTUVWXYZ', 3)()}`;
+
+  return {
+    id: uuidv4(),
+    code,
+    type,
+    name,
+  };
+};
+
+createSuggester(
+  'multiReferenceData',
+  'ReferenceData',
+  (search, { types }) => ({
+    type: { [Op.in]: types },
+    name: { [Op.iLike]: search },
+    ...VISIBILITY_CRITERIA,
+  }),
+  {
+    includeBuilder: (req) => {
+      const {
+        models: { ReferenceData, TaskTemplate },
+        query: { relationType },
+      } = req;
+
+      if (!relationType) return undefined;
+
+      return [
+        {
+          model: TaskTemplate,
+          as: 'taskTemplate',
+          include: TaskTemplate.getFullReferenceAssociations(),
+        },
+        {
+          model: ReferenceData,
+          as: 'children',
+          required: false,
+          through: {
+            attributes: [],
+            where: {
+              type: relationType,
+              deleted_at: null,
+            },
+          },
+          include: {
+            model: TaskTemplate,
+            as: 'taskTemplate',
+            include: TaskTemplate.getFullReferenceAssociations(),
+          },
+          where: VISIBILITY_CRITERIA,
+        },
+      ];
+    },
+    orderBuilder: (req) => {
+      const { query } = req;
+      const types = query.types;
+      if (!types?.length) return;
+
+      const caseStatement = query.types
+        .map((value, index) => `WHEN '${value}' THEN ${index + 1}`)
+        .join(' ');
+
+      return [
+        Sequelize.literal(`
+        CASE "ReferenceData"."type"
+          ${caseStatement}
+          ELSE ${query.types.length + 1}
+        END
+      `),
+      ];
+    },
+    mapper: (item) => item,
+    creatingBodyBuilder: (req) =>
+      referenceDataBodyBuilder({ type: req.body.type, name: req.body.name }),
+    afterCreated: afterCreatedReferenceData,
+  },
+  true,
+);
+
+REFERENCE_TYPE_VALUES.forEach((typeName) => {
   createSuggester(
     typeName,
     'ReferenceData',
-    search => ({
+    (search) => ({
       name: { [Op.iLike]: search },
       type: typeName,
       ...VISIBILITY_CRITERIA,
     }),
     {
-      includeBuilder: req => {
+      includeBuilder: (req) => {
         const {
           models: { ReferenceData },
           query: { parentId, relationType = DEFAULT_HIERARCHY_TYPE },
         } = req;
-
         if (!parentId) return undefined;
 
         return {
@@ -286,24 +396,9 @@ REFERENCE_TYPE_VALUES.forEach(typeName => {
           },
         };
       },
-      creatingBodyBuilder: req => {
-        const { body } = req;
-        if (!body.name) {
-          throw new ValidationError('Name is required');
-        }
-
-        const code = `${camelCase(body.name)}-${customAlphabet(
-          '1234567890ABCDEFGHIJKLMNPQRSTUVWXYZ',
-          3,
-        )()}`;
-
-        return {
-          id: uuidv4(),
-          code,
-          type: typeName,
-          name: body.name,
-        };
-      },
+      creatingBodyBuilder: (req) =>
+        referenceDataBodyBuilder({ type: typeName, name: req.body.name }),
+      afterCreated: afterCreatedReferenceData,
     },
     true,
   );
@@ -313,7 +408,7 @@ createSuggester('labTestType', 'LabTestType', () => VISIBILITY_CRITERIA, {
   mapper: ({ name, code, id, labTestCategoryId }) => ({ name, code, id, labTestCategoryId }),
 });
 
-const DEFAULT_WHERE_BUILDER = search => ({
+const DEFAULT_WHERE_BUILDER = (search) => ({
   name: { [Op.iLike]: search },
   ...VISIBILITY_CRITERIA,
 });
@@ -372,7 +467,7 @@ createSuggester(
     };
   },
   {
-    mapper: async location => {
+    mapper: async (location) => {
       const availability = await location.getAvailability();
       const { name, code, id, maxOccupancy, facilityId } = location;
 
@@ -398,6 +493,12 @@ createNameSuggester('facilityLocationGroup', 'LocationGroup', (search, query) =>
   filterByFacilityWhereBuilder(search, { ...query, filterByFacility: true }),
 );
 
+// Location groups filtered by isBookable. Used in location bookings view
+createNameSuggester('bookableLocationGroup', 'LocationGroup', (search, query) => ({
+  ...filterByFacilityWhereBuilder(search, { ...query, filterByFacility: true }),
+  isBookable: true,
+}));
+
 createNameSuggester('survey', 'Survey', (search, { programId }) => ({
   name: { [Op.iLike]: search },
   ...(programId ? { programId } : programId),
@@ -409,17 +510,17 @@ createNameSuggester('survey', 'Survey', (search, { programId }) => ({
 createSuggester(
   'invoiceProducts',
   'InvoiceProduct',
-  search => ({
+  (search) => ({
     name: { [Op.iLike]: search },
     '$referenceData.type$': REFERENCE_TYPES.ADDITIONAL_INVOICE_PRODUCT,
     ...VISIBILITY_CRITERIA,
   }),
   {
-    mapper: product => {
+    mapper: (product) => {
       product.addVirtualFields();
       return product;
     },
-    includeBuilder: req => {
+    includeBuilder: (req) => {
       return [
         {
           model: req.models.ReferenceData,
@@ -434,7 +535,7 @@ createSuggester(
 createSuggester(
   'practitioner',
   'User',
-  search => ({
+  (search) => ({
     displayName: { [Op.iLike]: search },
     ...VISIBILITY_CRITERIA,
   }),
@@ -447,38 +548,59 @@ createSuggester(
   },
 );
 
+// Remove whitespace from the start and end of each string then combine with a space in between
+// E.g. 'William ' + 'Horoto' => 'William Horoto'
+const trimAndConcat = (col1, col2) =>
+  Sequelize.fn(
+    'concat',
+    Sequelize.fn('trim', Sequelize.col(col1)),
+    ' ',
+    Sequelize.fn('trim', Sequelize.col(col2)),
+  );
 createSuggester(
   'patient',
   'Patient',
-  search => ({
+  (search) => ({
     [Op.or]: [
-      Sequelize.where(
-        Sequelize.fn('concat', Sequelize.col('first_name'), ' ', Sequelize.col('last_name')),
-        { [Op.iLike]: search },
-      ),
+      Sequelize.where(trimAndConcat('first_name', 'last_name'), { [Op.iLike]: search }),
+      Sequelize.where(trimAndConcat('last_name', 'first_name'), { [Op.iLike]: search }),
       { displayId: { [Op.iLike]: search } },
     ],
   }),
-  { mapper: patient => patient, searchColumn: 'first_name' },
+  {
+    mapper: (patient) => patient,
+    searchColumn: 'first_name',
+    orderBuilder: (req) => {
+      const searchQuery = (req.query.q || '').trim().toLowerCase();
+      const escapedQuery = req.db.escape(searchQuery);
+      const escapedPartialMatch = req.db.escape(`${searchQuery}%`);
+      return Sequelize.literal(`
+          CASE
+            WHEN LOWER(display_id) = ${escapedQuery} THEN 0
+            WHEN LOWER(display_id) LIKE ${escapedPartialMatch} THEN 1
+            WHEN LOWER(TRIM(first_name) || ' ' || TRIM(last_name)) LIKE ${escapedPartialMatch} THEN 2
+            WHEN LOWER(TRIM(last_name) || ' ' || TRIM(first_name)) LIKE ${escapedPartialMatch} THEN 3
+            ELSE 4
+          END
+        `);
+    },
+  },
 );
 
 // Specifically fetches lab test categories that have a lab request against a patient
 createSuggester(
   'patientLabTestCategories',
   'ReferenceData',
-  (search, query) => {
+  (search, query, req) => {
     const baseWhere = DEFAULT_WHERE_BUILDER(search);
 
     if (!query.patientId) {
       return { ...baseWhere, type: REFERENCE_TYPES.LAB_TEST_CATEGORY };
     }
 
-    return {
-      ...baseWhere,
-      type: REFERENCE_TYPES.LAB_TEST_CATEGORY,
-      id: {
-        [Op.in]: Sequelize.literal(
-          `(
+    const idBaseFilter = {
+      [Op.in]: Sequelize.literal(
+        `(
           SELECT DISTINCT(lab_test_category_id)
           FROM lab_requests
           INNER JOIN
@@ -488,12 +610,37 @@ createSuggester(
             AND encounters.deleted_at is null
             AND lab_requests.deleted_at is null
         )`,
-        ),
-      },
+      ),
+    };
+    const canListSensitive = req.ability.can('list', 'SensitiveLabRequest');
+    const idSensitiveFilter = {
+      [Op.in]: Sequelize.literal(
+        `(
+          SELECT DISTINCT(lab_test_types.lab_test_category_id)
+          FROM lab_requests
+          INNER JOIN encounters
+            ON (encounters.id = lab_requests.encounter_id)
+          INNER JOIN lab_tests
+            ON (lab_requests.id = lab_tests.lab_request_id)
+          INNER JOIN lab_test_types
+            ON (lab_test_types.id = lab_tests.lab_test_type_id)
+          WHERE lab_requests.status = :lab_request_status
+            AND encounters.patient_id = :patient_id
+            AND encounters.deleted_at is null
+            AND lab_requests.deleted_at is null
+            AND lab_test_types.is_sensitive IS FALSE
+        )`,
+      ),
+    };
+
+    return {
+      ...baseWhere,
+      type: REFERENCE_TYPES.LAB_TEST_CATEGORY,
+      id: canListSensitive ? idBaseFilter : idSensitiveFilter,
     };
   },
   {
-    extraReplacementsBuilder: query => ({
+    extraReplacementsBuilder: (query) => ({
       lab_request_status: query?.status || 'published',
       patient_id: query.patientId,
     }),
@@ -536,7 +683,7 @@ createSuggester(
     };
   },
   {
-    extraReplacementsBuilder: query => ({
+    extraReplacementsBuilder: (query) => ({
       lab_request_status: query?.status || 'published',
       patient_id: query.patientId,
     }),
@@ -581,7 +728,7 @@ createSuggester(
     };
   },
   {
-    extraReplacementsBuilder: query => ({
+    extraReplacementsBuilder: (query) => ({
       patient_id: query.patientId,
     }),
   },
@@ -648,20 +795,20 @@ createNameSuggester('template', 'Template', (search, query) => {
   };
 });
 
-const routerEndpoints = suggestions.stack.map(layer => {
+const routerEndpoints = suggestions.stack.map((layer) => {
   const path = layer.route.path.replace('/', '').replaceAll('$', '');
   const root = path.split('/')[0];
   return root;
 });
 const rootElements = [...new Set(routerEndpoints)];
-SUGGESTER_ENDPOINTS.forEach(endpoint => {
+SUGGESTER_ENDPOINTS.forEach((endpoint) => {
   if (!rootElements.includes(endpoint)) {
     throw new Error(
       `Suggester endpoint exists in shared constant but not included in router: ${endpoint}`,
     );
   }
 });
-rootElements.forEach(endpoint => {
+rootElements.forEach((endpoint) => {
   if (!SUGGESTER_ENDPOINTS.includes(endpoint)) {
     throw new Error(`Suggester endpoint not added to shared constant: ${endpoint}`);
   }
