@@ -1,11 +1,6 @@
 import _config from 'config';
 import { log } from '@tamanu/shared/services/logging';
 import { SYNC_DIRECTIONS } from '@tamanu/constants';
-import {
-  CURRENT_SYNC_TIME_KEY,
-  LAST_SUCCESSFUL_SYNC_PULL_KEY,
-  LAST_SUCCESSFUL_SYNC_PUSH_KEY,
-} from '@tamanu/shared/sync/constants';
 import {
   createSnapshotTable,
   dropAllSnapshotTables,
@@ -13,7 +8,10 @@ import {
   getModelsForDirection,
   saveIncomingChanges,
   waitForPendingEditsUsingSyncTick,
-} from '@tamanu/shared/sync';
+  CURRENT_SYNC_TIME_KEY,
+  LAST_SUCCESSFUL_SYNC_PULL_KEY,
+  LAST_SUCCESSFUL_SYNC_PUSH_KEY,
+} from '@tamanu/database/sync';
 
 import { pushOutgoingChanges } from './pushOutgoingChanges';
 import { pullIncomingChanges } from './pullIncomingChanges';
@@ -121,7 +119,7 @@ export class FacilitySyncManager {
     const startTime = new Date().getTime();
     this.currentStartTime = startTime;
 
-    log.info('FacilitySyncManager.attemptStart', { reason: this.reason, startTime });
+    log.info('FacilitySyncManager.attemptStart', { reason: JSON.stringify(this.reason), startTime });
 
     const pullSince = (await this.models.LocalSystemFact.get(LAST_SUCCESSFUL_SYNC_PULL_KEY)) || -1;
 
