@@ -39,6 +39,11 @@ export const globalSettings = {
           type: yup.boolean(),
           defaultValue: false,
         },
+        restrictUsersToSync: {
+          description: 'Restrict users from being able to sync based on permissions',
+          type: yup.boolean(),
+          defaultValue: false,
+        },
       },
     },
     ageDisplayFormat: {
@@ -46,11 +51,21 @@ export const globalSettings = {
       type: ageDisplayFormatSchema,
       defaultValue: ageDisplayFormatDefault,
     },
+    appointments: {
+      description: 'Appointment settings',
+      properties: {
+        maxRepeatingAppointmentsPerGeneration: {
+          description: 'The maximum number of appointments that can be generated at once',
+          type: yup.number().min(1),
+          defaultValue: 50,
+        },
+      },
+    },
     features: {
       description: 'Toggle features on/off',
       properties: {
         mandateSpecimenType: {
-          description: '_',
+          description: 'Make specimen type a required field when creating a new lab request',
           type: yup.boolean(),
           defaultValue: false,
         },
@@ -85,6 +100,11 @@ export const globalSettings = {
           type: yup.boolean(),
           defaultValue: false,
         },
+        enableTasking: {
+          description: 'Enable tasking tab/module on encounter view',
+          type: yup.boolean(),
+          defaultValue: false,
+        },
         registerNewPatient: {
           description: 'Allow the creation of new patient on mobile',
           type: yup.boolean(),
@@ -95,6 +115,11 @@ export const globalSettings = {
           type: yup.boolean(),
           defaultValue: true,
         },
+        hideUpcomingVaccines: {
+          description: 'Hide upcoming vaccines behind a button from the patient details page',
+          type: yup.boolean(),
+          defaultValue: false,
+        },
         enablePatientDeaths: {
           description: 'Enable death module',
           type: yup.boolean(),
@@ -158,6 +183,14 @@ export const globalSettings = {
             },
           },
         },
+        desktopCharting: {
+          properties: {
+            enabled: {
+              type: yup.boolean(),
+              defaultValue: false,
+            },
+          },
+        },
         idleTimeout: {
           description: 'Automatically logout idle users / inactive sessions after a certain time',
           properties: {
@@ -203,6 +236,22 @@ export const globalSettings = {
             },
           },
         },
+        disableInputPasting: {
+          description: 'Disable pasting into input fields (except email login and patient data fields)',
+          type: yup.boolean(),
+          defaultValue: false,
+        },
+        discharge: {
+          description:
+            'Encounter discharge configuration',
+          properties: {
+            dischargeNoteMandatory: {
+              type: yup.boolean(),
+              defaultValue: false,
+              unit: 'seconds',
+            },
+          },
+        },
       },
     },
     customisations: {
@@ -970,7 +1019,7 @@ export const globalSettings = {
         patientTabs: {
           description: 'The tabs on patient view',
           properties: {
-            history: {
+            summary: {
               description: '_',
               properties: unhideableLayoutModuleProperties,
             },
@@ -1011,6 +1060,10 @@ export const globalSettings = {
         sidebar: {
           description: 'The sidebar tabs in the facility',
           properties: {
+            dashboard: {
+              description: '_',
+              properties: layoutModuleProperties,
+            },
             patients: {
               description: '_',
               properties: {
@@ -1022,9 +1075,8 @@ export const globalSettings = {
             scheduling: {
               description: '_',
               properties: {
-                schedulingAppointments: { properties: layoutModuleProperties },
-                schedulingCalendar: { properties: layoutModuleProperties },
-                schedulingNew: { properties: layoutModuleProperties },
+                schedulingOutpatients: { properties: layoutModuleProperties },
+                schedulingLocations: { properties: layoutModuleProperties },
               },
             },
             medication: {
@@ -1058,11 +1110,40 @@ export const globalSettings = {
             },
           },
         },
+        patientView: {
+          description: 'The patient view in the facility',
+          properties: {
+            showLocationBookings: {
+              description: 'Show location bookings component on patient view',
+              type: yup.boolean(),
+              defaultValue: false,
+            },
+            showOutpatientAppointments: {
+              description: 'Show outpatient appointments component on patient view',
+              type: yup.boolean(),
+              defaultValue: false,
+            },
+          },
+        },
       },
     },
     templates: {
       description: 'Strings to be inserted into emails/PDFs',
       properties: {
+        appointmentConfirmation: {
+          description: 'The email sent to confirm an appointment',
+          properties: {
+            subject: {
+              type: yup.string().trim().min(1),
+              defaultValue: 'Appointment confirmation',
+            },
+            body: {
+              type: yup.string().trim().min(1),
+              defaultValue:
+                'Hi $firstName$ $lastName$,\n\n This is a confirmation that your appointment has been scheduled at $facilityName$.\nDate: $startDate$\nTime: $startTime$\nLocation: $locationName$, $facilityName$$clinicianName$\n\nDo not respond to this email.',
+            },
+          },
+        },
         letterhead: {
           description: 'The text at the top of most patient PDFs',
           properties: letterheadProperties,
@@ -1071,17 +1152,11 @@ export const globalSettings = {
           description: 'The email sent when the signer runs out',
           properties: {
             subject: {
-              type: yup
-                .string()
-                .trim()
-                .min(1),
+              type: yup.string().trim().min(1),
               defaultValue: 'Tamanu ICAO Certificate Signing Request',
             },
             body: {
-              type: yup
-                .string()
-                .trim()
-                .min(1),
+              type: yup.string().trim().min(1),
               defaultValue:
                 'Please sign the following certificate signing request (CSR) with the Country Signing Certificate Authority (CSCA), and return it to the Tamanu team or Tamanu deployment administration team.',
             },
@@ -1091,17 +1166,11 @@ export const globalSettings = {
           description: 'The email containing patient vaccine certificate',
           properties: {
             subject: {
-              type: yup
-                .string()
-                .trim()
-                .min(1),
+              type: yup.string().trim().min(1),
               defaultValue: 'Medical Certificate now available',
             },
             body: {
-              type: yup
-                .string()
-                .trim()
-                .min(1),
+              type: yup.string().trim().min(1),
               defaultValue:
                 'A medical certificate has been generated for you.\nYour certificate is available attached to this email.',
             },
@@ -1111,17 +1180,11 @@ export const globalSettings = {
           description: 'The email containing COVID patient vaccine certificate',
           properties: {
             subject: {
-              type: yup
-                .string()
-                .trim()
-                .min(1),
+              type: yup.string().trim().min(1),
               defaultValue: 'Medical Certificate now available',
             },
             body: {
-              type: yup
-                .string()
-                .trim()
-                .min(1),
+              type: yup.string().trim().min(1),
               defaultValue:
                 'A medical certificate has been generated for you.\nYour certificate is available attached to this email.',
             },
@@ -1131,17 +1194,11 @@ export const globalSettings = {
           description: 'Email with certificate containing the list of COVID tests for this patient',
           properties: {
             subject: {
-              type: yup
-                .string()
-                .trim()
-                .min(1),
+              type: yup.string().trim().min(1),
               defaultValue: 'Medical Certificate now available',
             },
             body: {
-              type: yup
-                .string()
-                .trim()
-                .min(1),
+              type: yup.string().trim().min(1),
               defaultValue:
                 'A medical certificate has been generated for you.\nYour certificate is attached to this email.',
             },
@@ -1152,17 +1209,11 @@ export const globalSettings = {
             'Certificate containing the list of COVID tests for this patient used for proof of over 13 days since infection',
           properties: {
             subject: {
-              type: yup
-                .string()
-                .trim()
-                .min(1),
+              type: yup.string().trim().min(1),
               defaultValue: 'COVID-19 Clearance Certificate now available',
             },
             body: {
-              type: yup
-                .string()
-                .trim()
-                .min(1),
+              type: yup.string().trim().min(1),
               defaultValue:
                 'A COVID-19 clearance certificate has been generated for you.\nYour certificate is attached to this email.',
             },
@@ -1183,10 +1234,7 @@ export const globalSettings = {
             },
             healthFacility: {
               description: '_',
-              type: yup
-                .string()
-                .trim()
-                .min(1),
+              type: yup.string().trim().min(1),
               defaultValue: 'State level',
             },
           },
@@ -1242,6 +1290,16 @@ export const globalSettings = {
       type: vitalEditReasonsSchema,
       defaultValue: vitalEditReasonsDefault,
     },
+    notifications: {
+      description: 'Notification settings',
+      properties: {
+        recentNotificationsTimeFrame: {
+          description: 'Settings for the time frame of recent notifications',
+          type: yup.number(),
+          defaultValue: 48,
+        }
+      }
+    },
   },
 };
 
